// src/index.ts
import installNodeFetch from "@hattip/polyfills/node-fetch";
import installGetSetCookie from "@hattip/polyfills/get-set-cookie";
import installCrypto from "@hattip/polyfills/crypto";
import process from "node:process";
import { Buffer } from "node:buffer";
installNodeFetch();
installGetSetCookie();
installCrypto();
function awsLambdaAdapter(handler) {
  return async (event, context) => {
    const ip = event.requestContext.http.sourceIp || event.headers["x-forwarded-for"] || "";
    const origin = process.env.ORIGIN || "https://" + event.requestContext.domainName;
    const url = origin + event.rawPath + (event.rawQueryString ? "?" + event.rawQueryString : "");
    const ctx = {
      request: new Request(url, {
        method: event.requestContext?.http?.method || "GET",
        body: !event.body || event.requestContext.http.method === "GET" || event.requestContext.http.method === "HEAD" ? void 0 : event.isBase64Encoded ? Buffer.from(event.body, "base64") : event.body,
        headers: event.headers
      }),
      ip,
      waitUntil(promise) {
      },
      passThrough() {
      },
      platform: {
        name: "aws-lambda",
        event,
        context
      },
      env(variable) {
        return process.env[variable];
      }
    };
    const response = await handler(ctx);
    const headers = {};
    let cookies = [];
    const uniqueHeaderNames = new Set(response.headers.keys());
    for (const key of uniqueHeaderNames) {
      if (key === "set-cookie") {
        const setCookie = response.headers.getSetCookie();
        cookies = setCookie;
      } else {
        headers[key] = response.headers.get(key);
      }
    }
    const resBody = response.body;
    let body;
    let isBase64Encoded = false;
    if (!resBody) {
      body = "";
    } else if (typeof resBody === "string") {
      body = resBody;
    } else if (resBody instanceof Uint8Array) {
      body = Buffer.from(resBody).toString("base64");
      isBase64Encoded = true;
    } else {
      const chunks = [];
      for await (const chunk of resBody) {
        if (typeof chunk === "string") {
          chunks.push(chunk);
        } else {
          chunks.push(chunk);
        }
      }
      switch (typeof chunks[0]) {
        case "undefined":
          body = "";
          break;
        case "string":
          body = chunks.join("");
          break;
        default:
          body = Buffer.concat(chunks).toString("base64");
          isBase64Encoded = true;
          break;
      }
    }
    const result = {
      statusCode: response.status,
      headers,
      cookies,
      body,
      isBase64Encoded
    };
    return result;
  };
}
export {
  awsLambdaAdapter as default
};
