// src/streaming.ts
import installNodeFetch from "@hattip/polyfills/node-fetch";
import installGetSetCookie from "@hattip/polyfills/get-set-cookie";
import installCrypto from "@hattip/polyfills/crypto";
import process from "node:process";
import { Buffer } from "node:buffer";
import { streamifyResponse } from "lambda-stream";
import { Readable } from "node:stream";
installNodeFetch();
installGetSetCookie();
installCrypto();
function awsLambdaAdapter(handler) {
  return streamifyResponse(
    async (event, responseStream, context) => {
      const ip = event.headers["x-forwarded-for"] || event.requestContext.http.sourceIp || "";
      const origin = process.env.ORIGIN || "https://" + event.requestContext.domainName;
      const url = origin + event.rawPath + (event.rawQueryString ? "?" + event.rawQueryString : "");
      const ctx = {
        request: new Request(url, {
          method: event.requestContext?.http?.method || "GET",
          body: !event.body || event.requestContext.http.method === "GET" || event.requestContext.http.method === "HEAD" ? void 0 : event.isBase64Encoded ? Buffer.from(event.body, "base64") : event.body,
          headers: event.headers
        }),
        ip,
        waitUntil(promise) {
        },
        passThrough() {
        },
        platform: {
          name: "aws-lambda-streaming",
          event,
          responseStream,
          context
        },
        env(variable) {
          return process.env[variable];
        }
      };
      const response = await handler(ctx);
      const headers = {};
      let cookies = [];
      const uniqueHeaderNames = new Set(response.headers.keys());
      for (const key of uniqueHeaderNames) {
        if (key === "set-cookie") {
          const setCookie = response.headers.getSetCookie();
          cookies = setCookie;
        } else {
          headers[key] = response.headers.get(key);
        }
      }
      responseStream = awslambda.HttpResponseStream.from(responseStream, {
        statusCode: response.status,
        headers,
        cookies
      });
      if (response.body) {
        const readable = Readable.fromWeb(response.body);
        readable.pipe(responseStream);
      } else {
        responseStream.write("");
        responseStream.end();
      }
      await new Promise((resolve, reject) => {
        responseStream.on("finish", resolve);
        responseStream.on("error", reject);
      });
    }
  );
}
export {
  awsLambdaAdapter as default
};
